#!/usr/bin/python3

import sys
from Utilities import unityRoot


def cycle_graph(n):
    """
    Devolve uma string text no padrão .in representando um grafo ciclo de n vértices
    
    Consulte o arquivo Utilities.py para a definição do padrão .in
    """
    text = "{}\n".format(n)
    text += "".join(["{:.4f} {:.4f}\n".format(*unityRoot(n)(n-k)) for k in range(n)])
    text += "{}\n".format(n)
    text += "".join(["{} {}\n".format(k, k+1) for k in range(n-1)] + ["{} {}\n".format(n-1, 0)])
    text += "2\n"
    text += "+" + "".join([" {}".format(k) for k in range(n)]) + "\n"
    text += "-" + "".join([" {}".format(k) for k in reversed(range(n))]) + "\n"
    return text

def wheel_graph(n):
    """
    Devolve uma string text no padrão .in representando um grafo roda de n vértices
    
    Consulte o arquivo Utilities.py para a definição do padrão .in
    """
    text = "{}\n".format(n)
    text += "0 0\n"
    text += "".join(["{:.4f} {:.4f}\n".format(*unityRoot(n-1)(n-1-k)) for k in range(n-1)])
    text += "{}\n".format(2*(n-1))
    text += "".join(["{} {}\n".format(k+1, k+2) for k in range(n-2)] + ["{} {}\n".format(n-1, 1)])
    text += "".join(["{} {}\n".format(0, k+1) for k in range(n-1)])
    text += "{}\n".format(n)
    text += "+ " + " ".join(map(str, range(n-1))) + "\n"
    text += "".join(["+ {} {} {}\n".format((n-1)+k+1, k, (n-1)+k) for k in range(n-2)] +
                    ["+ {} {} {}\n".format(n-1, n-2, 2*(n-1)-1)])
    return text

def bipartite_graph(n):
    """
    Devolve uma string text no padrão .in representando um K_{2,n}
    
    Consulte o arquivo Utilities.py para a definição do padrão .in
    """
    text = "{}\n".format(n+2)
    text += "-1 0\n"
    text += "".join(["0 {:.4f}\n".format(1*(n-1-k)/(n-1) + (-1)*k/(n-1)) for k in range(n)])
    text += "1 0\n"
    text += "{}\n".format(2*n)
    text += "".join(["{} {}\n".format(0, k+1) for k in range(n)])
    text += "".join(["{} {}\n".format(k+1, n+1) for k in range(n)])
    text += "{}\n".format(n)
    text += "+ " + "{} {} {} {}".format(0, n, 2*n-1, n-1) + "\n"
    text += "".join(["+ {} {} {} {}\n".format(k+1, n+k+1, n+k, k) for k in range(n-1)])
    return text

if __name__ == '__main__':
    f = locals()[sys.argv[1]]
    x = int(sys.argv[2]) if len(sys.argv) <= 3 else map(int, sys.argv[2:])
    print(f(x), end='')
